@@ -8,20 +8,113 @@ determining the forward and back azimuths and distance given the
 latitudes and longitudes of an initial and terminus point.
 """
 
-__all__ = ["Geod", "pj_ellps", "geodesic_version_str"]
+__all__ = [
+    "Geod",
+    "pj_ellps",
+    "geodesic_version_str",
+    "GeodIntermediateFlag",
+    "GeodIntermediateReturn",
+]
 
 import math
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from pyproj._geod import Geod as _Geod
-from pyproj._geod import geodesic_version_str
+from pyproj._geod import GeodIntermediateReturn, geodesic_version_str
+from pyproj.enums import GeodIntermediateFlag
 from pyproj.exceptions import GeodError
 from pyproj.list import get_ellps_map
-from pyproj.utils import _convertback, _copytobuffer
+from pyproj.utils import DataType, _convertback, _copytobuffer
 
 pj_ellps = get_ellps_map()
 
 
+def _params_from_ellps_map(ellps):
+    """
+    Build Geodesic parameters from PROJ ellips map
+
+    Parameter
+    ---------
+    ellps: str
+        The name of the ellips in the map.
+
+    Returns
+    -------
+    Tuple[float, float, float, float, bool]
+
+    """
+    ellps_dict = pj_ellps[ellps]
+    semi_major_axis: float = ellps_dict["a"]
+    sphere = False
+    if ellps_dict["description"] == "Normal Sphere":
+        sphere = True
+    if "b" in ellps_dict:
+        semi_minor_axis: float = ellps_dict["b"]
+        eccentricity_squared: float = 1.0 - semi_minor_axis**2 / semi_major_axis**2
+        flattening: float = (semi_major_axis - semi_minor_axis) / semi_major_axis
+    elif "rf" in ellps_dict:
+        flattening = 1.0 / ellps_dict["rf"]
+        semi_minor_axis = semi_major_axis * (1.0 - flattening)
+        eccentricity_squared = 1.0 - semi_minor_axis**2 / semi_major_axis**2
+    return semi_major_axis, semi_minor_axis, flattening, eccentricity_squared, sphere
+
+
+def _params_from_kwargs(kwargs):
+    """
+    Build Geodesic parameters from input kwargs:
+
+    - a: the semi-major axis (required).
+
+    Need least one of these parameters.
+
+    - b: the semi-minor axis
+    - rf: the reciprocal flattening
+    - f: flattening
+    - es: eccentricity squared
+
+
+    Parameter
+    ---------
+    ellps: str
+        The name of the ellips in the map.
+
+    Returns
+    -------
+    Tuple[float, float, float, float]
+
+    """
+    semi_major_axis = kwargs["a"]
+    if "b" in kwargs:
+        semi_minor_axis = kwargs["b"]
+        eccentricity_squared = 1.0 - semi_minor_axis**2 / semi_major_axis**2
+        flattening = (semi_major_axis - semi_minor_axis) / semi_major_axis
+    elif "rf" in kwargs:
+        flattening = 1.0 / kwargs["rf"]
+        semi_minor_axis = semi_major_axis * (1.0 - flattening)
+        eccentricity_squared = 1.0 - semi_minor_axis**2 / semi_major_axis**2
+    elif "f" in kwargs:
+        flattening = kwargs["f"]
+        semi_minor_axis = semi_major_axis * (1.0 - flattening)
+        eccentricity_squared = 1.0 - (semi_minor_axis / semi_major_axis) ** 2
+    elif "es" in kwargs:
+        eccentricity_squared = kwargs["es"]
+        semi_minor_axis = math.sqrt(
+            semi_major_axis**2 - eccentricity_squared * semi_major_axis**2
+        )
+        flattening = (semi_major_axis - semi_minor_axis) / semi_major_axis
+    elif "e" in kwargs:
+        eccentricity_squared = kwargs["e"] ** 2
+        semi_minor_axis = math.sqrt(
+            semi_major_axis**2 - eccentricity_squared * semi_major_axis**2
+        )
+        flattening = (semi_major_axis - semi_minor_axis) / semi_major_axis
+    else:
+        semi_minor_axis = semi_major_axis
+        flattening = 0.0
+        eccentricity_squared = 0.0
+    return semi_major_axis, semi_minor_axis, flattening, eccentricity_squared
+
+
 class Geod(_Geod):
     """
     performs forward and inverse geodetic, or Great Circle,
@@ -107,77 +200,47 @@ class Geod(_Geod):
         """
         # if initparams is a proj-type init string,
         # convert to dict.
-        ellpsd = {}  # type: Dict[str, Union[str, float]]
+        ellpsd: Dict[str, Union[str, float]] = {}
         if initstring is not None:
             for kvpair in initstring.split():
                 # Actually only +a and +b are needed
                 # We can ignore safely any parameter that doesn't have a value
                 if kvpair.find("=") == -1:
                     continue
-                k, v = kvpair.split("=")
-                k = k.lstrip("+")
-                if k in ["a", "b", "rf", "f", "es", "e"]:
-                    ellpsd[k] = float(v)
+                key, val = kvpair.split("=")
+                key = key.lstrip("+")
+                if key in ["a", "b", "rf", "f", "es", "e"]:
+                    ellpsd[key] = float(val)
                 else:
-                    ellpsd[k] = v
+                    ellpsd[key] = val
         # merge this dict with kwargs dict.
         kwargs = dict(list(kwargs.items()) + list(ellpsd.items()))
         sphere = False
         if "ellps" in kwargs:
-            # ellipse name given, look up in pj_ellps dict
-            ellps_dict = pj_ellps[kwargs["ellps"]]
-            a = ellps_dict["a"]  # type: float
-            if ellps_dict["description"] == "Normal Sphere":
-                sphere = True
-            if "b" in ellps_dict:
-                b = ellps_dict["b"]  # type: float
-                es = 1.0 - (b * b) / (a * a)  # type: float
-                f = (a - b) / a  # type: float
-            elif "rf" in ellps_dict:
-                f = 1.0 / ellps_dict["rf"]
-                b = a * (1.0 - f)
-                es = 1.0 - (b * b) / (a * a)
+            (
+                semi_major_axis,
+                semi_minor_axis,
+                flattening,
+                eccentricity_squared,
+                sphere,
+            ) = _params_from_ellps_map(kwargs["ellps"])
         else:
-            # a (semi-major axis) and one of
-            # b the semi-minor axis
-            # rf the reciprocal flattening
-            # f flattening
-            # es eccentricity squared
-            # must be given.
-            a = kwargs["a"]
-            if "b" in kwargs:
-                b = kwargs["b"]
-                es = 1.0 - (b * b) / (a * a)
-                f = (a - b) / a
-            elif "rf" in kwargs:
-                f = 1.0 / kwargs["rf"]
-                b = a * (1.0 - f)
-                es = 1.0 - (b * b) / (a * a)
-            elif "f" in kwargs:
-                f = kwargs["f"]
-                b = a * (1.0 - f)
-                es = 1.0 - (b / a) ** 2
-            elif "es" in kwargs:
-                es = kwargs["es"]
-                b = math.sqrt(a ** 2 - es * a ** 2)
-                f = (a - b) / a
-            elif "e" in kwargs:
-                es = kwargs["e"] ** 2
-                b = math.sqrt(a ** 2 - es * a ** 2)
-                f = (a - b) / a
-            else:
-                b = a
-                f = 0.0
-                es = 0.0
-                # msg='ellipse name or a, plus one of f,es,b must be given'
-                # raise ValueError(msg)
-        if math.fabs(f) < 1.0e-8:
+            (
+                semi_major_axis,
+                semi_minor_axis,
+                flattening,
+                eccentricity_squared,
+            ) = _params_from_kwargs(kwargs)
+
+        if math.fabs(flattening) < 1.0e-8:
             sphere = True
 
-        super().__init__(a, f, sphere, b, es)
+        super().__init__(
+            semi_major_axis, flattening, sphere, semi_minor_axis, eccentricity_squared
+        )
 
-    def fwd(
-        self, lons: Any, lats: Any, az: Any, dist: Any, radians=False
+    def fwd(  # pylint: disable=invalid-name
+        self, lons: Any, lats: Any, az: Any, dist: Any, radians: bool = False
     ) -> Tuple[Any, Any, Any]:
         """
         Forward transformation
@@ -186,43 +249,62 @@ class Geod(_Geod):
         points given longitudes and latitudes of initial points,
         plus forward azimuths and distances.
 
+        Accepted numeric scalar or array:
+
+        - :class:`int`
+        - :class:`float`
+        - :class:`numpy.floating`
+        - :class:`numpy.integer`
+        - :class:`list`
+        - :class:`tuple`
+        - :class:`array.array`
+        - :class:`numpy.ndarray`
+        - :class:`xarray.DataArray`
+        - :class:`pandas.Series`
+
         Parameters
         ----------
-        lons: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lons: scalar or array
             Longitude(s) of initial point(s)
-        lats: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lats: scalar or array
             Latitude(s) of initial point(s)
-        az: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        az: scalar or array
             Forward azimuth(s)
-        dist: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        dist: scalar or array
             Distance(s) between initial and terminus point(s)
             in meters
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Longitude(s) of terminus point(s)
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Latitude(s) of terminus point(s)
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Back azimuth(s)
         """
         # process inputs, making copies that support buffer API.
-        inx, xisfloat, xislist, xistuple = _copytobuffer(lons)
-        iny, yisfloat, yislist, yistuple = _copytobuffer(lats)
-        inz, zisfloat, zislist, zistuple = _copytobuffer(az)
-        ind, disfloat, dislist, distuple = _copytobuffer(dist)
+        inx, x_data_type = _copytobuffer(lons)
+        iny, y_data_type = _copytobuffer(lats)
+        inz, z_data_type = _copytobuffer(az)
+        ind = _copytobuffer(dist)[0]
         self._fwd(inx, iny, inz, ind, radians=radians)
         # if inputs were lists, tuples or floats, convert back.
-        outx = _convertback(xisfloat, xislist, xistuple, inx)
-        outy = _convertback(yisfloat, yislist, yistuple, iny)
-        outz = _convertback(zisfloat, zislist, zistuple, inz)
+        outx = _convertback(x_data_type, inx)
+        outy = _convertback(y_data_type, iny)
+        outz = _convertback(z_data_type, inz)
         return outx, outy, outz
 
     def inv(
-        self, lons1: Any, lats1: Any, lons2: Any, lats2: Any, radians=False
+        self,
+        lons1: Any,
+        lats1: Any,
+        lons2: Any,
+        lats2: Any,
+        radians: bool = False,
     ) -> Tuple[Any, Any, Any]:
         """
         Inverse transformation
@@ -230,39 +312,53 @@ class Geod(_Geod):
         Determine forward and back azimuths, plus distances
         between initial points and terminus points.
 
+        Accepted numeric scalar or array:
+
+        - :class:`int`
+        - :class:`float`
+        - :class:`numpy.floating`
+        - :class:`numpy.integer`
+        - :class:`list`
+        - :class:`tuple`
+        - :class:`array.array`
+        - :class:`numpy.ndarray`
+        - :class:`xarray.DataArray`
+        - :class:`pandas.Series`
+
         Parameters
         ----------
-        lons1: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lons1: scalar or array
             Longitude(s) of initial point(s)
-        lats1: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lats1: scalar or array
             Latitude(s) of initial point(s)
-        lons2: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lons2: scalar or array
             Longitude(s) of terminus point(s)
-        lats2: array, :class:`numpy.ndarray`, list, tuple, or scalar
+        lats2: scalar or array
             Latitude(s) of terminus point(s)
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Forward azimuth(s)
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Back azimuth(s)
-        array, :class:`numpy.ndarray`, list, tuple, or scalar:
+        scalar or array:
             Distance(s) between initial and terminus point(s)
             in meters
         """
         # process inputs, making copies that support buffer API.
-        inx, xisfloat, xislist, xistuple = _copytobuffer(lons1)
-        iny, yisfloat, yislist, yistuple = _copytobuffer(lats1)
-        inz, zisfloat, zislist, zistuple = _copytobuffer(lons2)
-        ind, disfloat, dislist, distuple = _copytobuffer(lats2)
+        inx, x_data_type = _copytobuffer(lons1)
+        iny, y_data_type = _copytobuffer(lats1)
+        inz, z_data_type = _copytobuffer(lons2)
+        ind = _copytobuffer(lats2)[0]
         self._inv(inx, iny, inz, ind, radians=radians)
         # if inputs were lists, tuples or floats, convert back.
-        outx = _convertback(xisfloat, xislist, xistuple, inx)
-        outy = _convertback(yisfloat, yislist, yistuple, iny)
-        outz = _convertback(zisfloat, zislist, zistuple, inz)
+        outx = _convertback(x_data_type, inx)
+        outy = _convertback(y_data_type, iny)
+        outz = _convertback(z_data_type, inz)
         return outx, outy, outz
 
     def npts(
@@ -273,13 +369,19 @@ class Geod(_Geod):
         lat2: float,
         npts: int,
         radians: bool = False,
+        initial_idx: int = 1,
+        terminus_idx: int = 1,
     ) -> List:
         """
+        .. versionadded:: 3.1.0 initial_idx, terminus_idx
+
         Given a single initial point and terminus point, returns
         a list of longitude/latitude pairs describing npts equally
         spaced intermediate points along the geodesic between the
         initial and terminus points.
 
+        Similar to inv_intermediate(), but with less options.
+
         Example usage:
 
         >>> from pyproj import Geod
@@ -336,17 +438,319 @@ class Geod(_Geod):
             Latitude of the terminus point
         npts: int
             Number of points to be returned
-        radians: bool, optional
+            (including initial and/or terminus points, if required)
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
-
+            Otherwise, the data is assumed to be in degrees.
+        initial_idx: int, default=1
+            if initial_idx==0 then the initial point would be included in the output
+            (as the first point)
+        terminus_idx: int, default=1
+            if terminus_idx==0 then the terminus point would be included in the output
+            (as the last point)
         Returns
         -------
         list of tuples:
             list of (lon, lat) points along the geodesic
             between the initial and terminus points.
         """
-        lons, lats = super()._npts(lon1, lat1, lon2, lat2, npts, radians=radians)
-        return list(zip(lons, lats))
+
+        res = self._inv_or_fwd_intermediate(
+            lon1=lon1,
+            lat1=lat1,
+            lon2_or_azi1=lon2,
+            lat2_or_nan=lat2,
+            npts=npts,
+            del_s=0,
+            radians=radians,
+            initial_idx=initial_idx,
+            terminus_idx=terminus_idx,
+            flags=GeodIntermediateFlag.AZIS_DISCARD,
+            out_lons=None,
+            out_lats=None,
+            out_azis=None,
+        )
+        return list(zip(res.lons, res.lats))
+
+    def inv_intermediate(
+        self,
+        lon1: float,
+        lat1: float,
+        lon2: float,
+        lat2: float,
+        npts: int = 0,
+        del_s: float = 0,
+        initial_idx: int = 1,
+        terminus_idx: int = 1,
+        radians: bool = False,
+        flags: GeodIntermediateFlag = GeodIntermediateFlag.DEFAULT,
+        out_lons: Any = None,
+        out_lats: Any = None,
+        out_azis: Any = None,
+    ) -> GeodIntermediateReturn:
+        """
+        .. versionadded:: 3.1.0
+
+        Given a single initial point and terminus point,
+        and the number of points, returns
+        a list of longitude/latitude pairs describing npts equally
+        spaced intermediate points along the geodesic between the
+        initial and terminus points.
+
+        npts and del_s parameters are mutually exclusive:
+
+        if npts != 0:
+            it calculates the distance between the points by
+            the distance between the initial point and the
+            terminus point divided by npts
+            (the number of intermediate points)
+        else:
+            it calculates the number of intermediate points by
+            dividing the distance between the initial and
+            terminus points by del_s
+            (delimiter distance between two successive points)
+
+        Similar to npts(), but with more options.
+
+        Example usage:
+
+        >>> from pyproj import Geod
+        >>> g = Geod(ellps='clrk66') # Use Clarke 1866 ellipsoid.
+        >>> # specify the lat/lons of Boston and Portland.
+        >>> boston_lat = 42.+(15./60.); boston_lon = -71.-(7./60.)
+        >>> portland_lat = 45.+(31./60.); portland_lon = -123.-(41./60.)
+        >>> # find ten equally spaced points between Boston and Portland.
+        >>> r = g.inv_intermediate(boston_lon,boston_lat,portland_lon,portland_lat,10)
+        >>> for lon,lat in zip(r.lons, r.lats): f'{lat:.3f} {lon:.3f}'
+        '43.528 -75.414'
+        '44.637 -79.883'
+        '45.565 -84.512'
+        '46.299 -89.279'
+        '46.830 -94.156'
+        '47.149 -99.112'
+        '47.251 -104.106'
+        '47.136 -109.100'
+        '46.805 -114.051'
+        '46.262 -118.924'
+        >>> # test with radians=True (inputs/outputs in radians, not degrees)
+        >>> import math
+        >>> dg2rad = math.radians(1.)
+        >>> rad2dg = math.degrees(1.)
+        >>> r = g.inv_intermediate(
+        ...    dg2rad*boston_lon,
+        ...    dg2rad*boston_lat,
+        ...    dg2rad*portland_lon,
+        ...    dg2rad*portland_lat,
+        ...    10,
+        ...    radians=True
+        ... )
+        >>> for lon,lat in zip(r.lons, r.lats): f'{rad2dg*lat:.3f} {rad2dg*lon:.3f}'
+        '43.528 -75.414'
+        '44.637 -79.883'
+        '45.565 -84.512'
+        '46.299 -89.279'
+        '46.830 -94.156'
+        '47.149 -99.112'
+        '47.251 -104.106'
+        '47.136 -109.100'
+        '46.805 -114.051'
+        '46.262 -118.924'
+
+        Parameters
+        ----------
+        lon1: float
+            Longitude of the initial point
+        lat1: float
+            Latitude of the initial point
+        lon2: float
+            Longitude of the terminus point
+        lat2: float
+            Latitude of the terminus point
+        npts: int, default=0
+            Number of points to be returned
+            npts == 0 if del_s != 0
+        del_s: float, default=0
+            delimiter distance between two successive points
+            del_s == 0 if npts != 0
+        radians: bool, default=False
+            If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
+        initial_idx: int, default=1
+            if initial_idx==0 then the initial point would be included in the output
+            (as the first point)
+        terminus_idx: int, default=1
+            if terminus_idx==0 then the terminus point would be included in the output
+            (as the last point)
+        flags: GeodIntermediateFlag, default=GeodIntermediateFlag.DEFAULT
+            * 1st - round/ceil/trunc (see ``GeodIntermediateFlag.NPTS_*``)
+            * 2nd - update del_s to the new npts or not
+                    (see ``GeodIntermediateFlag.DEL_S_*``)
+            * 3rd - if out_azis=None, indicates if to save or discard the azimuths
+                    (see ``GeodIntermediateFlag.AZIS_*``)
+            * default - round npts, update del_s accordingly, discard azis
+        out_lons: array, :class:`numpy.ndarray`, optional
+            Longitude(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+        out_lats: array, :class:`numpy.ndarray`, optional
+            Latitudes(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+        out_azis: array, :class:`numpy.ndarray`, optional
+            az12(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+            unless requested otherwise by the flags
+
+        Returns
+        -------
+        GeodIntermediateReturn:
+            number of points, distance and output arrays (GeodIntermediateReturn docs)
+        """
+        return super()._inv_or_fwd_intermediate(
+            lon1=lon1,
+            lat1=lat1,
+            lon2_or_azi1=lon2,
+            lat2_or_nan=lat2,
+            npts=npts,
+            del_s=del_s,
+            radians=radians,
+            initial_idx=initial_idx,
+            terminus_idx=terminus_idx,
+            flags=int(flags),
+            out_lons=out_lons,
+            out_lats=out_lats,
+            out_azis=out_azis,
+        )
+
+    def fwd_intermediate(
+        self,
+        lon1: float,
+        lat1: float,
+        azi1: float,
+        npts: int,
+        del_s: float,
+        initial_idx: int = 1,
+        terminus_idx: int = 1,
+        radians: bool = False,
+        flags: GeodIntermediateFlag = GeodIntermediateFlag.DEFAULT,
+        out_lons: Any = None,
+        out_lats: Any = None,
+        out_azis: Any = None,
+    ) -> GeodIntermediateReturn:
+        """
+        .. versionadded:: 3.1.0
+
+        Given a single initial point and azimuth, number of points (npts)
+        and delimiter distance between two successive points (del_s), returns
+        a list of longitude/latitude pairs describing npts equally
+        spaced intermediate points along the geodesic between the
+        initial and terminus points.
+
+        Example usage:
+
+        >>> from pyproj import Geod
+        >>> g = Geod(ellps='clrk66') # Use Clarke 1866 ellipsoid.
+        >>> # specify the lat/lons of Boston and Portland.
+        >>> boston_lat = 42.+(15./60.); boston_lon = -71.-(7./60.)
+        >>> portland_lat = 45.+(31./60.); portland_lon = -123.-(41./60.)
+        >>> az12,az21,dist = g.inv(boston_lon,boston_lat,portland_lon,portland_lat)
+        >>> # find ten equally spaced points between Boston and Portland.
+        >>> npts = 10
+        >>> del_s = dist/(npts+1)
+        >>> r = g.fwd_intermediate(boston_lon,boston_lat,az12,npts=npts,del_s=del_s)
+        >>> for lon,lat in zip(r.lons, r.lats): f'{lat:.3f} {lon:.3f}'
+        '43.528 -75.414'
+        '44.637 -79.883'
+        '45.565 -84.512'
+        '46.299 -89.279'
+        '46.830 -94.156'
+        '47.149 -99.112'
+        '47.251 -104.106'
+        '47.136 -109.100'
+        '46.805 -114.051'
+        '46.262 -118.924'
+        >>> # test with radians=True (inputs/outputs in radians, not degrees)
+        >>> import math
+        >>> dg2rad = math.radians(1.)
+        >>> rad2dg = math.degrees(1.)
+        >>> r = g.fwd_intermediate(
+        ...    dg2rad*boston_lon,
+        ...    dg2rad*boston_lat,
+        ...    dg2rad*az12,
+        ...    npts=npts,
+        ...    del_s=del_s,
+        ...    radians=True
+        ... )
+        >>> for lon,lat in zip(r.lons, r.lats): f'{rad2dg*lat:.3f} {rad2dg*lon:.3f}'
+        '43.528 -75.414'
+        '44.637 -79.883'
+        '45.565 -84.512'
+        '46.299 -89.279'
+        '46.830 -94.156'
+        '47.149 -99.112'
+        '47.251 -104.106'
+        '47.136 -109.100'
+        '46.805 -114.051'
+        '46.262 -118.924'
+
+        Parameters
+        ----------
+        lon1: float
+            Longitude of the initial point
+        lat1: float
+            Latitude of the initial point
+        azi1: float
+            Azimuth from the initial point towards the terminus point
+        npts: int
+            Number of points to be returned
+            (including initial and/or terminus points, if required)
+        del_s: float
+            delimiter distance between two successive points
+        radians: bool, default=False
+            If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
+        initial_idx: int, default=1
+            if initial_idx==0 then the initial point would be included in the output
+            (as the first point)
+        terminus_idx: int, default=1
+            if terminus_idx==0 then the terminus point would be included in the output
+            (as the last point)
+        flags: GeodIntermediateFlag, default=GeodIntermediateFlag.DEFAULT
+            * 1st - round/ceil/trunc (see ``GeodIntermediateFlag.NPTS_*``)
+            * 2nd - update del_s to the new npts or not
+                    (see ``GeodIntermediateFlag.DEL_S_*``)
+            * 3rd - if out_azis=None, indicates if to save or discard the azimuths
+                    (see ``GeodIntermediateFlag.AZIS_*``)
+            * default - round npts, update del_s accordingly, discard azis
+        out_lons: array, :class:`numpy.ndarray`, optional
+            Longitude(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+        out_lats: array, :class:`numpy.ndarray`, optional
+            Latitudes(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+        out_azis: array, :class:`numpy.ndarray`, optional
+            az12(s) of the intermediate point(s)
+            If None then buffers would be allocated internnaly
+            unless requested otherwise by the flags
+
+        Returns
+        -------
+        GeodIntermediateReturn:
+            number of points, distance and output arrays (GeodIntermediateReturn docs)
+        """
+        return super()._inv_or_fwd_intermediate(
+            lon1=lon1,
+            lat1=lat1,
+            lon2_or_azi1=azi1,
+            lat2_or_nan=math.nan,
+            npts=npts,
+            del_s=del_s,
+            radians=radians,
+            initial_idx=initial_idx,
+            terminus_idx=terminus_idx,
+            flags=int(flags),
+            out_lons=out_lons,
+            out_lats=out_lats,
+            out_azis=out_azis,
+        )
 
     def line_length(self, lons: Any, lats: Any, radians: bool = False) -> float:
         """
@@ -371,8 +775,9 @@ class Geod(_Geod):
             The longitude points along a line.
         lats: array, :class:`numpy.ndarray`, list, tuple, or scalar
             The latitude points along a line.
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
@@ -380,8 +785,8 @@ class Geod(_Geod):
             The total length of the line (meters).
         """
         # process inputs, making copies that support buffer API.
-        inx, xisfloat, xislist, xistuple = _copytobuffer(lons)
-        iny, yisfloat, yislist, yistuple = _copytobuffer(lats)
+        inx = _copytobuffer(lons)[0]
+        iny = _copytobuffer(lats)[0]
         return self._line_length(inx, iny, radians=radians)
 
     def line_lengths(self, lons: Any, lats: Any, radians: bool = False) -> Any:
@@ -405,8 +810,9 @@ class Geod(_Geod):
             The longitude points along a line.
         lats: array, :class:`numpy.ndarray`, list, tuple, or scalar
             The latitude points along a line.
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
@@ -414,11 +820,11 @@ class Geod(_Geod):
             The total length of the line (meters).
         """
         # process inputs, making copies that support buffer API.
-        inx, xisfloat, xislist, xistuple = _copytobuffer(lons)
-        iny, yisfloat, yislist, yistuple = _copytobuffer(lats)
+        inx, x_data_type = _copytobuffer(lons)
+        iny = _copytobuffer(lats)[0]
         self._line_length(inx, iny, radians=radians)
-        line_lengths = _convertback(xisfloat, xislist, xistuple, inx)
-        return line_lengths if xisfloat else line_lengths[:-1]
+        line_lengths = _convertback(x_data_type, inx)
+        return line_lengths if x_data_type == DataType.FLOAT else line_lengths[:-1]
 
     def polygon_area_perimeter(
         self, lons: Any, lats: Any, radians: bool = False
@@ -457,8 +863,9 @@ class Geod(_Geod):
             An array of longitude values.
         lats: array, :class:`numpy.ndarray`, list, tuple, or scalar
             An array of latitude values.
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
@@ -493,8 +900,9 @@ class Geod(_Geod):
         ----------
         geometry: :class:`shapely.geometry.BaseGeometry`
             The geometry to calculate the length from.
-        radians: bool, optional
+        radians: bool, default=False
             If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
@@ -507,7 +915,7 @@ class Geod(_Geod):
             pass
         if hasattr(geometry, "exterior"):
             return self.geometry_length(geometry.exterior, radians=radians)
-        elif hasattr(geometry, "geoms"):
+        if hasattr(geometry, "geoms"):
             total_length = 0.0
             for geom in geometry.geoms:
                 total_length += self.geometry_length(geom, radians=radians)
@@ -555,16 +963,17 @@ class Geod(_Geod):
         ...         holes=[LineString([Point(1, 2), Point(3, 4), Point(5, 2)])],
         ...     )
         ... )
-        >>> f"{poly_area:.3f} {poly_perimeter:.3f}"
-        '944373881400.339 3979008.036'
+        >>> f"{poly_area:.0f} {poly_perimeter:.0f}"
+        '944373881400 3979008'
 
 
         Parameters
         ----------
         geometry: :class:`shapely.geometry.BaseGeometry`
             The geometry to calculate the area and perimeter from.
-        radians: bool, optional
-            If True, the input data is assumed to be in radians. Default is degrees.
+        radians: bool, default=False
+            If True, the input data is assumed to be in radians.
+            Otherwise, the data is assumed to be in degrees.
 
         Returns
         -------
@@ -588,7 +997,7 @@ class Geod(_Geod):
                 total_area += area
             return total_area, total_perimeter
         # multi geometries
-        elif hasattr(geometry, "geoms"):
+        if hasattr(geometry, "geoms"):
             total_area = 0.0
             total_perimeter = 0.0
             for geom in geometry.geoms:
@@ -602,11 +1011,11 @@ class Geod(_Geod):
         # search for ellipse name
         for (ellps, vals) in pj_ellps.items():
             if self.a == vals["a"]:
-                b = vals.get("b", None)
-                rf = vals.get("rf", None)
                 # self.sphere is True when self.f is zero or very close to
                 # zero (0), so prevent divide by zero.
-                if self.b == b or (not self.sphere and (1.0 / self.f) == rf):
+                if self.b == vals.get("b") or (
+                    not self.sphere and (1.0 / self.f) == vals.get("rf")
+                ):
                     return f"{self.__class__.__name__}(ellps={ellps!r})"
 
         # no ellipse name found, call super class
